Class: ScoutApm::Config::ConfigFile

Inherits:
Object
  • Object
show all
Defined in:
lib/scout_apm/config.rb

Overview

Attempts to load a configuration file, and parse it as YAML. If the file is not found, inaccessbile, or unparsable, log a message to that effect, and move on.

Instance Method Summary collapse

Constructor Details

#initialize(context, file_path = nil, config = {}) ⇒ ConfigFile

Returns a new instance of ConfigFile.



481
482
483
484
485
486
# File 'lib/scout_apm/config.rb', line 481

def initialize(context, file_path=nil, config={})
  @context = context
  @config = config || {}
  @resolved_file_path = file_path || determine_file_path
  load_file(@resolved_file_path)
end

Instance Method Details

#any_keys_found?Boolean

Returns:

  • (Boolean)


501
502
503
504
505
# File 'lib/scout_apm/config.rb', line 501

def any_keys_found?
  KNOWN_CONFIG_OPTIONS.any? { |option|
    @settings.has_key?(option)
  }
end

#has_key?(key) ⇒ Boolean

Returns:

  • (Boolean)


497
498
499
# File 'lib/scout_apm/config.rb', line 497

def has_key?(key)
  @settings.has_key?(key)
end

#nameObject



507
508
509
# File 'lib/scout_apm/config.rb', line 507

def name
  "config-file"
end

#value(key) ⇒ Object



488
489
490
491
492
493
494
495
# File 'lib/scout_apm/config.rb', line 488

def value(key)
  if @file_loaded
    val = @settings[key]
    val.to_s.strip.length.zero? ? nil : val
  else
    nil
  end
end