Class: ScoutApm::Config::ConfigNull
- Inherits:
-
Object
- Object
- ScoutApm::Config::ConfigNull
- Defined in:
- lib/scout_apm/config.rb
Overview
Good News: It has every config value you could want Bad News: The content of that config value is always nil Used for the null-object pattern
Instance Method Summary collapse
Instance Method Details
#any_keys_found? ⇒ Boolean
443 444 445 |
# File 'lib/scout_apm/config.rb', line 443 def any_keys_found? false end |
#has_key? ⇒ Boolean
439 440 441 |
# File 'lib/scout_apm/config.rb', line 439 def has_key?(*) true end |
#name ⇒ Object
447 448 449 |
# File 'lib/scout_apm/config.rb', line 447 def name "no-config" end |
#value ⇒ Object
435 436 437 |
# File 'lib/scout_apm/config.rb', line 435 def value(*) nil end |